<?php
/**
 * Adds Recent comments with avatar Widget
 */
if ( ! class_exists( 'Cihuatl_Recent_Comments' ) ) {
	class Cihuatl_Recent_Comments extends WP_Widget {

		/**
		 * Register widget with WordPress.
		 */
		function __construct() {
			parent::__construct(
				'cihuatl_recent_comments', // Base ID
				esc_html__( 'Cihuatl Recent Comments with avatar', 'cihuatl' ), // Name
				array( 'description' => esc_html__( 'Display the latest comments with avatar', 'cihuatl' ) ) // Args
			);
		}

		/**
		 * Front-end display of widget.
		 *
		 * @see WP_Widget::widget()
		 *
		 * @param array $args     Widget arguments.
		 * @param array $instance Saved values from database.
		 */
		public function widget( $args, $instance ) {
			echo $args['before_widget'];
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
			}

            $number_of_comments = ! empty( $instance['number_of_comments'] ) ? intval( $instance['number_of_comments'] ) : 5;

			// WP_Comment_Query arguments
			$comments_args = array(
				'status'    => 'approve',
				'type'      => 'comment',
				'post_type' => 'post',
				'number'    => $number_of_comments,
				'orderby'   => 'comment_date',
			);

			// The Comment Query
			$recent_comments = new WP_Comment_Query( $comments_args );

			$comments = $recent_comments->comments;

			if ( $comments ) {
				foreach ( $comments as $comment ) {
					?>
					<a href="<?php the_permalink( $comment->comment_post_ID ); ?>#comment-<?php echo $comment->comment_ID; ?>" class="lt-comment">
						<div class="lt-comment-avatar">
							<?php echo get_avatar( $comment->comment_author_email ); ?>
						</div>
						<div class="lt-comment-content">
							<span class="lt-comment-author"><?php echo $comment->comment_author; ?>:</span> <?php echo wp_kses( $comment->comment_content, array() ); ?>
						</div>
					</a>
					<?php
				}
			}
			echo $args['after_widget'];
		}

		/**
		 * Back-end widget form.
		 *
		 * @see WP_Widget::form()
		 *
		 * @param array $instance Previously saved values from database.
		 */
		public function form( $instance ) {
			$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'Recent Comments', 'cihuatl' );

			$number_of_comments = ! empty( $instance['number_of_comments'] ) ? intval( $instance['number_of_comments'] ) : 5;

			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'cihuatl' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'number_of_comments' ) ); ?>"><?php esc_html_e( 'Number of comments to be displayed:', 'cihuatl' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number_of_comments' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number_of_comments' ) ); ?>" type="text" value="<?php echo esc_attr( $number_of_comments ); ?>">
			</p>
			<?php
		}

		/**
		 * Sanitize widget form values as they are saved.
		 *
		 * @see WP_Widget::update()
		 *
		 * @param array $new_instance Values just sent to be saved.
		 * @param array $old_instance Previously saved values from database.
		 *
		 * @return array Updated safe values to be saved.
		 */
		public function update( $new_instance, $old_instance ) {
			$instance          = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';

			$instance['number_of_comments'] = ( ! empty( $new_instance['number_of_comments'] ) ) ? intval( $new_instance['number_of_comments'] ) : 5;

			return $instance;
		}

	} // class Cihuatl_Recent_Comments
}

// register Cihuatl_Recent_Comments widget
function register_recent_comments_widget() {
	register_widget( 'Cihuatl_Recent_Comments' );
}
add_action( 'widgets_init', 'register_recent_comments_widget' );
