<?php
/**
 * Customizer settings for this theme.
 *
 * @package WordPress
 * @subpackage Cihuatl
 * @since 1.0.0
 */

if ( ! class_exists( 'Cihuatl_Customize' ) ) {
	/**
	 * CUSTOMIZER SETTINGS
	 */
	class Cihuatl_Customize {

		/**
		 * Register customizer options.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public static function register( $wp_customize ) {

			/**
			 * Site Title & Description.
			 * */
			$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
			$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

			$wp_customize->selective_refresh->add_partial(
				'blogname',
				array(
					'selector'        => '.site-title a',
					'render_callback' => 'cihuatl_customize_partial_blogname',
				)
			);

			$wp_customize->selective_refresh->add_partial(
				'blogdescription',
				array(
					'selector'        => '.site-description',
					'render_callback' => 'cihuatl_customize_partial_blogdescription',
				)
			);

			$wp_customize->selective_refresh->add_partial(
				'custom_logo',
				array(
					'selector'        => '.header-titles [class*=site-]:not(.site-description)',
					'render_callback' => 'cihuatl_customize_partial_site_logo',
				)
			);

			$wp_customize->selective_refresh->add_partial(
				'retina_logo',
				array(
					'selector'        => '.header-titles [class*=site-]:not(.site-description)',
					'render_callback' => 'cihuatl_customize_partial_site_logo',
				)
			);

			/**
			 * Site Identity
			 */

			/* 2X Header Logo ---------------- */
			$wp_customize->add_setting(
				'retina_logo',
				array(
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => array( __CLASS__, 'sanitize_checkbox' ),
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_control(
				'retina_logo',
				array(
					'type'        => 'checkbox',
					'section'     => 'title_tagline',
					'priority'    => 10,
					'label'       => __( 'Retina logo', 'cihuatl' ),
					'description' => __( 'Scales the logo to half its uploaded size, making it sharp on high-res screens.', 'cihuatl' ),
				)
			);

			// Header & Footer Background Color.
			$wp_customize->add_setting(
				'header_footer_background_color',
				array(
					'default'           => '#343a40',
					'sanitize_callback' => 'sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'header_footer_background_color',
					array(
						'label'   => __( 'Header &amp; Footer Background Color', 'cihuatl' ),
						'section' => 'colors',
					)
				)
			);

			// Update background color with postMessage, so inline CSS output is updated as well.
			$wp_customize->get_setting( 'background_color' )->transport = 'postMessage';

			/**
			 * Theme Options
			 */

			$wp_customize->add_section(
				'options',
				array(
					'title'      => __( 'Theme Options', 'cihuatl' ),
					'priority'   => 40,
					'capability' => 'edit_theme_options',
				)
			);

			/* Enable Header Search ----------------------------------------------- */

			$wp_customize->add_setting(
				'enable_header_search',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => true,
					'sanitize_callback' => array( __CLASS__, 'sanitize_checkbox' ),
				)
			);

			$wp_customize->add_control(
				'enable_header_search',
				array(
					'type'     => 'checkbox',
					'section'  => 'options',
					'priority' => 10,
					'label'    => __( 'Show search in header', 'cihuatl' ),
				)
			);

			/* Show author bio ---------------------------------------------------- */

			$wp_customize->add_setting(
				'show_author_bio',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => true,
					'sanitize_callback' => array( __CLASS__, 'sanitize_checkbox' ),
				)
			);

			$wp_customize->add_control(
				'show_author_bio',
				array(
					'type'     => 'checkbox',
					'section'  => 'options',
					'priority' => 10,
					'label'    => __( 'Show author bio', 'cihuatl' ),
				)
			);

			/* Display related posts ---------------------------------------------- */

			$wp_customize->add_setting(
				'show_related_posts',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => true,
					'sanitize_callback' => array( __CLASS__, 'sanitize_checkbox' ),
				)
			);

			$wp_customize->add_control(
				'show_related_posts',
				array(
					'type'     => 'checkbox',
					'section'  => 'options',
					'priority' => 10,
					'label'    => __( 'Show related posts', 'cihuatl' ),
				)
			);

			/* Slider ------------------------------------------------------------ */

			/**
			 * Slider
			 */

			$wp_customize->add_section(
				'slider',
				array(
					'title'      => __( 'Slider Options', 'cihuatl' ),
					'priority'   => 40,
					'capability' => 'edit_theme_options',
				)
			);

			$wp_customize->add_setting(
				'show_slider',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => true,
					'sanitize_callback' => array( __CLASS__, 'sanitize_checkbox' ),
				)
			);

			$wp_customize->add_control(
				'show_slider',
				array(
					'type'     => 'checkbox',
					'section'  => 'slider',
					'priority' => 7,
					'label'    => __( 'Show slider on home page', 'cihuatl' ),
				)
			);

			$wp_customize->add_setting(
				'number_of_slides',
				array(
					'capability' => 'edit_theme_options',
					'default'    => 5,
					'sanitize_callback' => array( __CLASS__, 'sanitize_integer' )
				)
			);

			$wp_customize->add_control(
				'number_of_slides',
				array(
					'type'     => 'text',
					'section'  => 'slider',
					'priority' => 7,
					'label'    => __( 'Number of posts to display', 'cihuatl' ),
				)
			);

			$wp_customize->add_setting(
				'slider_content',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => 'latest',
					'sanitize_callback' => array( __CLASS__, 'sanitize_select' ),
				)
			);

			$wp_customize->add_control(
				'slider_content',
				array(
					'type'     => 'radio',
					'section'  => 'slider',
					'priority' => 8,
					'label'    => __( 'Content to display:', 'cihuatl' ),
					'choices'  => array(
						'latest'   => __( 'Latest Blog posts', 'cihuatl' ),
						'category' => __( 'Posts inside a particular category', 'cihuatl' ),
					),
				)
			);

			$wp_customize->add_setting(
				'slider_category',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => 'latest',
					'sanitize_callback' => array( __CLASS__, 'sanitize_select' ),
				)
			);

			$wp_customize->add_control(
				'slider_category',
				array(
					'type'     => 'select',
					'section'  => 'slider',
					'priority' => 9,
					'label'    => __( 'Choose one category:', 'cihuatl' ),
					'choices'  => cihuatl_get_all_categories(),
				)
			);

			/* Display full content or excerpts on the blog and archives --------- */

			$wp_customize->add_setting(
				'blog_content',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => 'summary',
					'sanitize_callback' => array( __CLASS__, 'sanitize_select' ),
				)
			);

			$wp_customize->add_control(
				'blog_content',
				array(
					'type'     => 'radio',
					'section'  => 'options',
					'priority' => 10,
					'label'    => __( 'On archive pages, posts show:', 'cihuatl' ),
					'choices'  => array(
						'full'    => __( 'Full text', 'cihuatl' ),
						'summary' => __( 'Summary', 'cihuatl' ),
					),
				)
			);

			/* Sidebar position -------------------------------------------------- */

			$wp_customize->add_setting(
				'sidebar_position',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => 'right',
					'sanitize_callback' => array( __CLASS__, 'sanitize_select' ),
				)
			);

			$wp_customize->add_control(
				'sidebar_position',
				array(
					'type'     => 'radio',
					'section'  => 'options',
					'priority' => 10,
					'label'    => __( 'Sidebar position:', 'cihuatl' ),
					'choices'  => array(
						'right' => __( 'Right', 'cihuatl' ),
						'left'  => __( 'Left', 'cihuatl' ),
						'none'  => __( 'Delete sidebar', 'cihuatl' ),
					),
				)
			);

		}

		/**
		 * Sanitize select.
		 *
		 * @param string $input The input from the setting.
		 * @param object $setting The selected setting.
		 *
		 * @return string $input|$setting->default The input from the setting or the default setting.
		 */
		public static function sanitize_select( $input, $setting ) {
			$input   = sanitize_key( $input );
			$choices = $setting->manager->get_control( $setting->id )->choices;
			return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
		}

		/**
		 * Sanitize boolean for checkbox.
		 *
		 * @param bool $checked Whether or not a box is checked.
		 *
		 * @return bool
		 */
		public static function sanitize_checkbox( $checked ) {
			return ( ( isset( $checked ) && true === $checked ) ? true : false );
		}

        /**
         * Sanitize integer
         *
         * @param integer $integer Integer
         *
         * @return integer
         */
        public static function sanitize_integer( $integer ) {
            return intval( $integer );
        }



	}

	// Setup the Theme Customizer settings and controls.
	add_action( 'customize_register', array( 'Cihuatl_Customize', 'register' ) );

}

/**
 * PARTIAL REFRESH FUNCTIONS
 * */
if ( ! function_exists( 'cihuatl_customize_partial_blogname' ) ) {
	/**
	 * Render the site title for the selective refresh partial.
	 */
	function cihuatl_customize_partial_blogname() {
		bloginfo( 'name' );
	}
}

if ( ! function_exists( 'cihuatl_customize_partial_blogdescription' ) ) {
	/**
	 * Render the site description for the selective refresh partial.
	 */
	function cihuatl_customize_partial_blogdescription() {
		bloginfo( 'description' );
	}
}

if ( ! function_exists( 'cihuatl_customize_partial_site_logo' ) ) {
	/**
	 * Render the site logo for the selective refresh partial.
	 *
	 * Doing it this way so we don't have issues with `render_callback`'s arguments.
	 */
	function cihuatl_customize_partial_site_logo() {
		cihuatl_site_logo();
	}
}


/**
 * Input attributes for cover overlay opacity option.
 *
 * @return array Array containing attribute names and their values.
 */
function cihuatl_customize_opacity_range() {
	/**
	 * Filter the input attributes for opacity
	 *
	 * @param array $attrs {
	 *     The attributes
	 *
	 *     @type int $min Minimum value
	 *     @type int $max Maximum value
	 *     @type int $step Interval between numbers
	 * }
	 */
	return apply_filters(
		'cihuatl_customize_opacity_range',
		array(
			'min'  => 0,
			'max'  => 90,
			'step' => 5,
		)
	);
}

/**
 * Get all used categories in the blog
 *
 * @return array
 */
function cihuatl_get_all_categories() {
	$categories_array = array();
	$categories       = get_categories();
	foreach ( $categories as $category ) {
		$categories_array[ $category->term_id ] = $category->name;
	}
	return $categories_array;
}
