<?php
/**
 * Custom comment walker for this theme.
 *
 * @package WordPress
 * @subpackage Cihuatl
 * @since Cihuatl 1.0
 */

if ( ! class_exists( 'Cihuatl_Walker_Comment' ) ) {
	/**
	 * CUSTOM COMMENT WALKER
	 * A custom walker for comments, based on the walker in Twenty Nineteen.
	 */
	class Cihuatl_Walker_Comment extends Walker_Comment {

		/**
		 * Outputs a comment in the HTML5 format.
		 *
		 * @see wp_list_comments()
		 * @see https://developer.wordpress.org/reference/functions/get_comment_author_url/
		 * @see https://developer.wordpress.org/reference/functions/get_comment_author/
		 * @see https://developer.wordpress.org/reference/functions/get_avatar/
		 * @see https://developer.wordpress.org/reference/functions/get_comment_reply_link/
		 * @see https://developer.wordpress.org/reference/functions/get_edit_comment_link/
		 *
		 * @param WP_Comment $comment Comment to display.
		 * @param int        $depth   Depth of the current comment.
		 * @param array      $args    An array of arguments.
		 */
		protected function html5_comment( $comment, $depth, $args ) {

			$tag = ( 'div' === $args['style'] ) ? 'div' : 'li';

			?>
			<<?php echo $tag; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- static output ?> id="comment-<?php comment_ID(); ?>" <?php comment_class( $this->has_children ? 'parent' : '', $comment ); ?>>
				<article id="div-comment-<?php comment_ID(); ?>" class="comment-block">
					<div class="comment-avatar">
						<?php
						$comment_author_url = get_comment_author_url( $comment );
						$comment_author     = get_comment_author( $comment );
						$avatar             = get_avatar( $comment, $args['avatar_size'] );
						if ( 0 !== $args['avatar_size'] ) {
							echo wp_kses_post( $avatar );
						}
						?>
					</div><!-- .comment-avatar -->

					   <div class="comment-content">

						   <div class="comment-meta">
							   <?php
								if ( ! empty( $comment_author_url ) ) {
									printf( '<a href="%s" rel="external nofollow" class="url">', $comment_author_url ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped --Escaped in https://developer.wordpress.org/reference/functions/get_comment_author_url/
								}

								printf(
									'<cite class="fn">%1$s</cite>',
									esc_html( $comment_author )
								);

							   if ( ! empty( $comment_author_url ) ) {
								   echo '</a>';
							   }
								?>

							   <a href="<?php echo esc_url( get_comment_link( $comment, $args ) ); ?>">
								   <?php
									/* translators: 1: Comment date, 2: Comment time. */
									$comment_timestamp = sprintf( __( '%1$s at %2$s', 'cihuatl' ), get_comment_date( '', $comment ), get_comment_time() );
									?>
								   <time datetime="<?php comment_time( 'c' ); ?>" title="<?php echo esc_attr( $comment_timestamp ); ?>">
									   <?php echo esc_html( $comment_timestamp ); ?>
								   </time>
							   </a>
							   <?php
								if ( get_edit_comment_link() ) {
									echo ' <span aria-hidden="true">&bull;</span> <a class="comment-edit-link" href="' . esc_url( get_edit_comment_link() ) . '">' . esc_html_x( 'Edit', 'verb', 'cihuatl' ) . '</a>';
								}
								?>
						   </div><!-- .comment-meta -->

						   <div class="comment-body">
						   <?php
							   comment_text();

							if ( '0' === $comment->comment_approved ) {
								?>
								   <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'cihuatl' ); ?></p>
								   <?php
							}

							?>
						   </div><!-- .comment-body -->
							<?php

							$comment_reply_link = get_comment_reply_link(
								array_merge(
									$args,
									array(
										'add_below' => 'div-comment',
										'depth'     => $depth,
										'max_depth' => $args['max_depth'],
										'before'    => '<span class="reply">',
										'after'     => '</span>',
									)
								)
							);

							if ( $comment_reply_link ) {
								echo $comment_reply_link;
							}
							?>

					   </div><!-- .comment-content -->
				</article>

			<?php
		}
	}
}