<?php
/**
 * The template file for displaying the comments and comment form for the
 * Cihuatl theme.
 *
 * @package WordPress
 * @subpackage Cihuatl
 * @since Cihuatl 1.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
*/
if ( post_password_required() ) {
	return;
}

if ( $comments ) {
	?>

	<div class="comments" id="comments">

		<?php
		$comments_number = absint( get_comments_number() );
		?>

		<div class="comments-header section-inner small max-percentage">

			<h2 class="comment-reply-title">
			<?php
			if ( ! have_comments() ) {
				esc_html_e( 'Leave a comment', 'cihuatl' );
			} elseif ( 1 === $comments_number ) {
				/* translators: %s: Post title. */
				printf( esc_html_x( 'One reply on &ldquo;%s&rdquo;', 'comments title', 'cihuatl' ), esc_html( get_the_title() ) );
			} else {
				printf(
					/* translators: 1: Number of comments, 2: Post title. */
					_nx(
						'%1$s reply on &ldquo;%2$s&rdquo;',
						'%1$s replies on &ldquo;%2$s&rdquo;',
						$comments_number,
						'comments title',
						'cihuatl'
					),
					number_format_i18n( $comments_number ),
					esc_html( get_the_title() )
				);
			}

			?>
			</h2><!-- .comments-title -->

		</div><!-- .comments-header -->

		<div class="comments-inner section-inner thin max-percentage">

			<?php
			wp_list_comments(
				array(
					'walker'      => new Cihuatl_Walker_Comment(),
					'avatar_size' => 120,
					'style'       => 'div',
				)
			);

			$comment_pagination = paginate_comments_links(
				array(
					'echo'      => false,
					'end_size'  => 0,
					'mid_size'  => 0,
					'next_text' => __( 'Newer Comments', 'cihuatl' ) . ' <span aria-hidden="true">&rarr;</span>',
					'prev_text' => '<span aria-hidden="true">&larr;</span> ' . __( 'Older Comments', 'cihuatl' ),
				)
			);

			if ( $comment_pagination ) {
				$pagination_classes = '';

				// If we're only showing the "Next" link, add a class indicating so.
				if ( false === strpos( $comment_pagination, 'prev page-numbers' ) ) {
					$pagination_classes = ' only-next';
				}
				?>

				<nav class="comments-pagination pagination<?php echo $pagination_classes; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- static output ?>" aria-label="<?php esc_attr_e( 'Comments', 'cihuatl' ); ?>">
					<?php echo wp_kses_post( $comment_pagination ); ?>
				</nav>

				<?php
			}
			?>

		</div><!-- .comments-inner -->

	</div><!-- comments -->

	<?php
}

if ( comments_open() || pings_open() ) {

	if ( $comments ) {
		echo '<hr class="styled-separator is-style-wide" aria-hidden="true" />';
	}

	$fields = array(
		'author' => sprintf(
			'<p class="form-row comment-form-author"><div class="form-group">%s</div></p>',
			sprintf(
				'<input id="author" class="form-control" name="author" placeholder="%s%s" type="text" value="%s" size="30" maxlength="245"%s />',
				__( 'Name', 'cihuatl' ),
				( $req ? '*' : '' ),
				esc_attr( $commenter['comment_author'] ),
                ( $req ? ' required="required"' : '' )
			)
		),
		'email'  => sprintf(
			'<p class="form-row comment-form-email"><div class="form-group">%s</div></p>',
			sprintf(
				'<input id="email" class="form-control" name="email" placeholder="%s%s" %s value="%s" size="30" maxlength="100" aria-describedby="email-notes"%s />',
				__( 'Email', 'cihuatl' ),
				( $req ? '*' : '' ),
				'type="email"',
				esc_attr( $commenter['comment_author_email'] ),
                ( $req ? ' required="required"' : '' )
			)
		),
		'url'    => sprintf(
			'<p class="form-row comment-form-url"><div class="form-group">%s</div></p>',
			sprintf(
				'<input id="url" class="form-control" name="url" placeholder="%s" %s value="%s" size="30" maxlength="200" />',
				__( 'Website', 'cihuatl' ),
				'type="url"',
				esc_attr( $commenter['comment_author_url'] )
			)
		),
	);

	$textarea = sprintf(
		'<p class="comment-form-comment form-group">%s %s</p>',
		sprintf(
			'<label for="comment">%s*</label>',
			esc_html_x( 'Comment', 'noun', 'cihuatl' )
		),
		'<textarea id="comment" class="form-control" name="comment" cols="45" rows="8" maxlength="65525" required="required"></textarea>'
	);

	$submit_button = '<input class="btn btn-outline-dark mb-2" name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" />';

	comment_form(
		array(
			'class_form'         => 'section-inner thin max-percentage',
			'id_form'            => 'comment-form',
			'title_reply_before' => '<h2 id="reply-title" class="comment-reply-title">',
			'title_reply_after'  => '</h2>',
			'format'             => 'html5',
			'fields'             => $fields,
			'comment_field'      => $textarea,
			'submit_button'      => $submit_button,
		)
	);

} elseif ( is_single() ) {

	if ( $comments ) {
		echo '<hr class="styled-separator is-style-wide" aria-hidden="true" />';
	}

	?>

	<div class="comment-respond" id="respond">

		<p class="comments-closed"><?php _e( 'Comments are closed.', 'cihuatl' ); ?></p>

	</div><!-- #respond -->

	<?php
}
