<?php
/**
 * The default template for displaying posts in archives
 *
 * Used for search result pages and archives
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package WordPress
 * @subpackage Cihuatl
 * @since Cihuatl 1.0
 */

?>
<?php get_header(); ?>

<?php get_template_part( 'template-parts/slider' ); ?>

	<?php

	$archive_title    = '';
	$archive_subtitle = '';

	if ( is_search() ) {
		global $wp_query;

		$archive_title = sprintf(
			'%1$s %2$s',
			'<span class="color-accent">' . esc_html_x( 'Search:', 'noun', 'cihuatl' ) . '</span>',
			'&ldquo;' . get_search_query() . '&rdquo;'
		);

		if ( $wp_query->found_posts ) {
			$archive_subtitle = sprintf(
				/* translators: %s: Number of search results. */
				_n(
					'We found %s result for your search.',
					'We found %s results for your search.',
					$wp_query->found_posts,
					'cihuatl'
				),
				number_format_i18n( $wp_query->found_posts )
			);
		} else {
			$archive_subtitle = __( 'We could not find any results for your search. You can give it another try through the search form below.', 'cihuatl' );
		}
	} elseif ( ! is_home() ) {
		$archive_title    = get_the_archive_title();
		$archive_subtitle = get_the_archive_description();
	}

	if ( $archive_title || $archive_subtitle ) {
		?>

		<div class="container-fluid" id="page-title">

			<div class="container">

				<?php if ( $archive_title ) { ?>
					<h1 class="archive-title"><?php echo wp_kses_post( $archive_title ); ?></h1>
				<?php } ?>

				<?php if ( $archive_subtitle ) { ?>
					<div class="archive-subtitle section-inner thin max-percentage intro-text"><?php echo wp_kses_post( wpautop( $archive_subtitle ) ); ?></div>
				<?php } ?>

			</div>

		</div><!-- .container-fluid -->

		<?php
	}
	?>

<div class="container-fluid" id="content-wrapper">

	<div class="container" id="main">

		<div class="row">

			<section class="col-12 col-md-8 col-lg-9" id="posts">
				<?php
				if ( have_posts() ) {
					while ( have_posts() ) {
						the_post();
						get_template_part( 'template-parts/content', get_post_type() );
					}
				}
				?>
			</section>

			<?php if ( get_theme_mod( 'sidebar_position', 'right' ) != 'none' && is_active_sidebar( 'right-sidebar' ) ) : ?>

				<div class="col-12 col-md-4 col-lg-3" id="sidebar">

					<?php dynamic_sidebar( 'right-sidebar' ); ?>

				</div>

			<?php endif; ?>

		</div> <!-- .row -->

		<?php get_template_part( 'template-parts/pagination' ); ?>

	</div> <!-- .main -->

</div> <!-- .content-wrapper -->

<?php get_template_part( 'template-parts/footer-menus-widgets' ); ?>

<?php get_footer(); ?>
